/* eslint-disable */
// 表单验证
const validate = {
  /**
     * 手机号码验证
     * 用法  phone: [
            {
              required: true,
              message: "请输入手机号码",
              trigger: "blur"
            },
            {
              validator: rulesPhone,-------------------------------
              trigger: 'blur'
            }
       ],
     */
  rulesPhone: (rule, value, callback) => {
    if (!/^1[23456789]\d{9}$/.test(value)) {
      callback(new Error("请输入正确的手机号"));
    } else {
      callback();
    }
  },
  /**
   * 数字验证
   */
  rulesNumber: (rule, value, callback) => {
    if (!/^[0-9]*$/.test(value)) {
      callback(new Error("请输入数字"));
    } else {
      callback();
    }
  },
  rulesTwoNumber: (rule, value, callback) => {
    if (
      !/^(([1-9][0-9]*)|(([0]\.\d{1,2}|[1-9][0-9]*\.\d{1,2})))$/.test(value)
    ) {
      callback(new Error("请输入正确格式"));
    } else {
      callback();
    }
  },
  // ^[^0]\d{1,3}$|^100$
  rulesNumberHander: (rule, value, callback) => {
    if (!/(^[1-9][0-9]$)|(^100&)|(^[1-9]$)$/.test(value)) {
      callback(new Error("请输入1-100的数字"));
    } else {
      callback();
    }
  },
  /**
   * 正整数验证
   * var regu = /^[1-9]\d*$/;
   * var regu = /^([1-9][0-9]*){1,3}$/;
   * var regu = /^\+?[1-9][0-9]*$/;
   */
  positiveInteger: (rule, value, callback) => {
    if (!/^[1-9]\d*$/.test(value)) {
      callback(new Error("请输入正整数"));
    } else {
      callback();
    }
  },
  /**
   * A positive real number with two decimal places
   * 验证有两位小数的正数
   * 注意：必须加type=number,该正则 0和正整数 会通过验证
   */
  positiveTwoDecimal: (rule, value, callback) => {
    let val = typeof value === "number" ? value + "" : "0";
    if (val === "0") {
      callback(new Error("请输入两位小数的正数"));
    } else if (!/^[0-9]+(.[0-9]{2})?$/.test(val) || /^[1-9]\d*$/.test(val)) {
      callback(new Error("请输入两位小数的正数"));
    } else {
      callback();
    }
  },
  /**
   * 验证有1-2位小数的正数
   * 注意：必须加type=number,该正则 0和正整数 会通过验证
   */
  positiveTwoOrOneDecimal: (rule, value, callback) => {
    let val = typeof value === "number" ? value.toString() : "0";
    if (val === "0") {
      callback(new Error("请输入1-2位小数的正数"));
    } else if (!/^[0-9]+(.[0-9]{1,2})?$/.test(val) || /^[1-9]\d*$/.test(val)) {
      callback(new Error("请输入1-2位小数的正数"));
    } else {
      callback();
    }
  },
  /**
     * ------------------------------表单验证----第二种用法-------------------------------
     * 密码验证---只能输入6-12个字母、数字、下划线
     * password: [{
          validator: validatePass,
          trigger: 'blur'
        }, {
          min: 6,
          max: 12,
          message: '长度在 6 到 12 个字符'
        }, {
          pattern: rulesPassword,--------------------------------
          message: '只能输入6-12个字母、数字、下划线'
        }],
    */
  rulesPassword: /^(\w){6,12}$/,
  // 手机号验证---手机号格式不正确
  rulesPhonePattern: /^1[23456789]\d{9}$/,
  // 正整数
  validatorInteger: /^[1-9]\d*$/,
  // 密码2验证---只能输入  以字母开头，长度在2-5之间， 只能包含字符、数字和下划线
  rulesPassword2: /^[a-zA-Z]w{1,4}$/,
  // 用户名只能为中文-验证---只能输入中文
  rulesUserName: /^[\u4E00-\u9FA5]+$/,
  // 身份证ID验证---身份证格式不正确
  rulesPeopleID: /(^\d{15}$)|(^\d{18}$)|(^\d{17}(\d|X|x)$)/,
  // 护照ID验证---护照格式不正确
  rulesHuzhao: /^((1[45]\d{7})|(G\d{8})|(P\d{7})|(S\d{7,8}))?$/,
  // email验证---邮箱格式不正确
  rulesEmail: /^[\w-]+(\.[\w-]+)*@[\w-]+(\.[\w-]+)+$/,
  // 邮政编码验证---邮政编码格式不正确（开头不能为0，共6位）
  rulesYZCode: /^[1-9][0-9]{5}$/,
  /**
     * 车牌号验证---常规格式：晋B12345
     * 用法：carId:[
            {required: true, message: '请输入车牌号', trigger: 'blur'},
            {pattern:rulesCarId,--------------------
             message: '常规格式：晋B12345'},
        ],
     */
  rulesCarId: /(^[\u4E00-\u9FA5]{1}[A-Z0-9]{6}$)|(^[A-Z]{2}[A-Z0-9]{2}[A-Z0-9\u4E00-\u9FA5]{1}[A-Z0-9]{4}$)|(^[\u4E00-\u9FA5]{1}[A-Z0-9]{5}[挂学警军港澳]{1}$)|(^[A-Z]{2}[0-9]{5}$)|(^(08|38){1}[A-Z0-9]{4}[A-Z0-9挂学警军港澳]{1}$)/
};

export default validate;
/**
验证数字的正则表达式集
验证数字：^[0-9]*$
验证n位的数字：^\d{n}$
验证至少n位数字：^\d{n,}$
验证m-n位的数字：^\d{m,n}$
验证零和非零开头的数字：^(0|[1-9][0-9]*)$
验证有两位小数的正实数：^[0-9]+(.[0-9]{2})?$
验证有1-3位小数的正实数：^[0-9]+(.[0-9]{1,3})?$
验证非零的正整数：^\+?[1-9][0-9]*$
验证非零的负整数：^\-[1-9][0-9]*$
验证非负整数（正整数 + 0） ^\d+$
验证非正整数（负整数 + 0） ^((-\d+)|(0+))$
验证长度为3的字符：^.{3}$
验证由26个英文字母组成的字符串：^[A-Za-z]+$
验证由26个大写英文字母组成的字符串：^[A-Z]+$
验证由26个小写英文字母组成的字符串：^[a-z]+$
验证由数字和26个英文字母组成的字符串：^[A-Za-z0-9]+$
验证由数字、26个英文字母或者下划线组成的字符串：^\w+$
验证用户密码:^[a-zA-Z]\w{5,17}$ 正确格式为：以字母开头，长度在6-18之间，只能包含字符、数字和下划线。
验证是否含有 ^%&',;=?$\" 等字符：[^%&',;=?$\x22]+
验证汉字：^[\u4e00-\u9fa5],{0,}$
验证Email地址：/^([a-zA-Z0-9]+[_|\_|\.]?)*[a-zA-Z0-9]+@([a-zA-Z0-9]+[_|\_|\.]?)*[a-zA-Z0-9]+\.[a-zA-Z]{2,3}$/
验证InternetURL：^http://([\w-]+\.)+[\w-]+(/[\w-./?%&=]*)?$ ；^[a-zA-z]+://(w+(-w+)*)(.(w+(-w+)*))*(?S*)?$
验证电话号码：^(\(\d{3,4}\)|\d{3,4}-)?\d{7,8}$：--正确格式为：XXXX-XXXXXXX，XXXX-XXXXXXXX，XXX-XXXXXXX，XXX-XXXXXXXX，XXXXXXX，XXXXXXXX。
验证身份证号（15位或18位数字）：^\d{15}|\d{}18$
验证一年的12个月：^(0?[1-9]|1[0-2])$ 正确格式为：“01”-“09”和“1”“12”
验证一个月的31天：^((0?[1-9])|((1|2)[0-9])|30|31)$ 正确格式为：01、09和1、31。
整数：^-?\d+$
非负浮点数（正浮点数 + 0）：^\d+(\.\d+)?$
正浮点数 ^(([0-9]+\.[0-9]*[1-9][0-9]*)|([0-9]*[1-9][0-9]*\.[0-9]+)|([0-9]*[1-9][0-9]*))$
非正浮点数（负浮点数 + 0） ^((-\d+(\.\d+)?)|(0+(\.0+)?))$
负浮点数 ^(-(([0-9]+\.[0-9]*[1-9][0-9]*)|([0-9]*[1-9][0-9]*\.[0-9]+)|([0-9]*[1-9][0-9]*)))$
浮点数 ^(-?\d+)(\.\d+)?$
------------------------
----原生JS写法
<script type="text/javascript">
  function SubmitCk() {
    var reg = /^([a-zA-Z0-9]+[_|\_|\.]?)*[a-zA-Z0-9]+@([a-zA-Z0-9]+[_|\_|\.]?)*[a-zA-Z0-9]+\.[a-zA-Z]{2,3}$/;
    if (!reg.test($("#txtEmail").val())) {
      alert("请输入正确邮箱地址")
      return false;
    }
  }
</script>
 */
